@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: common.py,v 1.26 2004/11/29 07:36:02 atzm Exp $
+# $Id: common.py,v 1.30 2005/09/09 19:09:05 atzm Exp $
 #
 
 import os, sys
@@ -19,7 +19,7 @@ import gtk
 
 # common defines
 APP = 'GBottler'
-VER = '0.1.4'
+VER = '0.1.5'
 
 VOTE  = "Vote"
 AGREE = "Agree"
@@ -29,17 +29,12 @@ LIBDIR = "~/.bottlecase"
 AGENT_NAME = os.path.basename(sys.argv[0])
 HOST = "bottle.mikage.to"
 
-STYLE_TALK = 1
-STYLE_SCRIPT = 2
-STYLE_SCRIPT_WITH_LINEFEED = 3
+STYLE_TALK = 0
+STYLE_SCRIPT = 1
+STYLE_SCRIPT_WITH_LINEFEED = 2
 
-POS_NEXT  = 'pos_next'
-POS_PREV  = 'pos_prev'
-POS_FIRST = 'pos_leftmost'
-POS_END   = 'pos_rightmost'
-
-STATE_BOTTLE_PLAYING  = gtk.STOCK_REFRESH
-STATE_BOTTLE_RESERVED = gtk.STOCK_APPLY
+STATE_BOTTLE_PLAYING  = gtk.STOCK_MEDIA_PLAY
+STATE_BOTTLE_RESERVED = gtk.STOCK_MEDIA_RECORD
 STATE_BOTTLE_NONE     = ''
 
 DL_SUFFIX_PATTERNS = {
@@ -88,14 +83,14 @@ def get_icon_button(stock, size=gtk.ICON_SIZE_MENU,
 	b.show()
 
 	if label:
-		h = gtk.HBox(gtk.FALSE, 0)
+		h = gtk.HBox(False, 0)
 		h.set_border_width(0)
 		h.show()
-		h.pack_start(i, gtk.TRUE, gtk.TRUE, 0)
+		h.pack_start(i, True, True, 0)
 
 		l = gtk.Label(label)
 		l.show()
-		h.pack_start(l, gtk.TRUE, gtk.TRUE, 0)
+		h.pack_start(l, True, True, 0)
 		b.add(h)
 	else:
 		b.add(i)
@@ -110,11 +105,11 @@ def get_icon_box(stock, label, size=gtk.ICON_SIZE_MENU):
 	l = gtk.Label(label)
 	l.show()
 
-	h = gtk.HBox(gtk.FALSE, 0)
+	h = gtk.HBox(False, 0)
 	h.set_border_width(0)
 	h.show()
-	h.pack_start(i, gtk.FALSE, gtk.TRUE, 0)
-	h.pack_start(l, gtk.FALSE, gtk.TRUE, 0)
+	h.pack_start(i, False, True, 0)
+	h.pack_start(l, False, True, 0)
 
 	return h
 
@@ -139,10 +134,10 @@ def get_hbox_with_label_button(stock, label, size=gtk.ICON_SIZE_MENU,
 	e.set_events(gtk.gdk.BUTTON_PRESS_MASK)
 	e.add(l)
 
-	h = gtk.HBox(gtk.FALSE, 0)
+	h = gtk.HBox(False, 0)
 	h.set_border_width(0)
-	h.pack_start(e, gtk.FALSE, gtk.TRUE, 0)
-	h.pack_end(b, gtk.FALSE, gtk.TRUE, 0)
+	h.pack_start(e, False, True, 0)
+	h.pack_end(b, False, True, 0)
 	h.show()
 
 	return h, e, b
