@@ -10,45 +10,36 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: logbook.py,v 1.4 2004/10/14 15:03:22 atzm Exp $
+# $Id: logbook.py,v 1.7 2005/09/08 20:03:43 atzm Exp $
 #
 
 import gtk
 from loglist import LogList
 from common  import *
+import config
 
 class LogBook(gtk.Notebook):
 	def __init__(self, label_text):
 		self.current_label_text = label_text
 
 		gtk.Notebook.__init__(self)
-		self.set_scrollable(gtk.TRUE)
+		self.set_scrollable(True)
 		self.set_tab_pos(gtk.POS_TOP)
 		self.show()
 
-		self.set_create_tab_position(POS_NEXT)
-
 	def get_n_pages(self):
 		# override for PyGTK 2.3 or earlier
 		return len(self.get_children())
 
-	def set_create_tab_position(self, pos):
-		self.create_position = pos
-
-	def get_create_tab_position(self, pos=None):
-		if not pos:
-			pos = self.create_position
-
-		if pos == POS_NEXT:
+	def get_create_tab_position(self):
+		pos = config.get('logwindow', 'new_page_placement', 'int')
+		if pos == config.LOGWINDOW_PAGE_PLACEMENT_NEXT:
 			return self.get_current_page() + 1
-		elif pos == POS_PREV:
-			p = self.get_current_page()
-			if p > 0:
-				p -= 1
-			return p
-		elif pos == POS_FIRST:
+		elif pos == config.LOGWINDOW_PAGE_PLACEMENT_PREV:
+			return self.get_current_page()
+		elif pos == config.LOGWINDOW_PAGE_PLACEMENT_LEFTMOST:
 			return 0
-		elif pos == POS_END:
+		elif pos == config.LOGWINDOW_PAGE_PLACEMENT_RIGHTMOST:
 			return -1
 		else:
 			raise ValueError, 'chan to basho shitei site kure'
@@ -69,8 +60,8 @@ class LogBook(gtk.Notebook):
 		self.remove_page(n)
 		return self.get_current_page()
 
-	def create_tab(self, label_text, pos=None, focus=False, list=None):
-		pos = self.get_create_tab_position(pos)
+	def create_tab(self, label_text, list=None):
+		pos = self.get_create_tab_position()
 
 		new_tab = LogList()
 
@@ -89,7 +80,7 @@ class LogBook(gtk.Notebook):
 		if list:
 			new_tab.set_local_log(list)
 
-		if focus:
+		if config.get('logwindow', 'focus_new_page', 'boolean'):
 			self.set_current_page(pos)
 
 		return button, eventbox, sw
@@ -160,7 +151,7 @@ class LogBook(gtk.Notebook):
 	def get_current_button_and_child(self):
 		# getting close button and ScrolledWindow inside LogList named `Current'
 		tabs = self.get_children()
-		for i in range(len(tabs)):
+		for i in xrange(len(tabs)):
 			hbox = self.get_tab_label(tabs[i])
 			eventbox, button = hbox.get_children()
 			label = eventbox.get_children()[0]
@@ -176,14 +167,14 @@ class LogBook(gtk.Notebook):
 
 		list.search(arrow, text, widget, data)
 
-	def update(self, mid, channel, ghost, script, datetime, pos=None, focus=False):
+	def update(self, mid, channel, ghost, script, datetime):
 		current_tab = self.get_current_loglist()
 
 		button   = None
 		eventbox = None
 		sw       = None
 		if not current_tab:
-			button, eventbox, sw = self.create_tab(self.current_label_text, pos=pos, focus=focus)
+			button, eventbox, sw = self.create_tab(self.current_label_text)
 			current_tab = sw.get_child()
 
 		current_tab.update(mid, channel, ghost, script, datetime)
