@@ -10,7 +10,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: loglist.py,v 1.3 2004/10/14 15:03:22 atzm Exp $
+# $Id: loglist.py,v 1.5 2005/08/29 19:03:24 atzm Exp $
 #
 
 import gtk, gobject
@@ -46,23 +46,23 @@ class LogList(gtk.TreeView):
 			]
 
 		l = 0
-		for i in range(len(columns)):
+		for i in xrange(len(columns)):
 			self.append_column(columns[i])
 			if l == self.LISTSTORE_PLAYING or l == self.LISTSTORE_URL:
 				cell = gtk.CellRendererPixbuf()
-				columns[i].pack_start(cell, gtk.FALSE)
+				columns[i].pack_start(cell, False)
 				columns[i].add_attribute(cell, 'stock-id', l)
 				l += 1
 			cell = gtk.CellRendererText()
-			columns[i].pack_start(cell, gtk.FALSE)
+			columns[i].pack_start(cell, False)
 			columns[i].add_attribute(cell, 'text', l)
-			columns[i].set_resizable(gtk.TRUE)
-			columns[i].set_clickable(gtk.FALSE)
+			columns[i].set_resizable(True)
+			columns[i].set_clickable(False)
 			l += 1
 
-		self.set_rules_hint(gtk.TRUE)
-		self.set_search_column(gtk.TRUE)
-		self.set_reorderable(gtk.FALSE)
+		self.set_rules_hint(True)
+		self.set_search_column(True)
+		self.set_reorderable(False)
 		self.set_size_request(450, 120)
 		self.connect('cursor-changed', self.cursor_changed)
 		self.show()
@@ -103,11 +103,11 @@ class LogList(gtk.TreeView):
 		liststore = self.get_model()
 		if liststore is None:
 			return ''
-		iter = liststore.get_iter(row)
-		return liststore.get_value(iter, col)
+		liter = liststore.get_iter(row)
+		return liststore.get_value(liter, col)
 
-	def cursor_changed(self, loglist, se=gtk.FALSE):
-		loglist.emit('select-cursor-row', gtk.FALSE)
+	def cursor_changed(self, loglist, se=False):
+		loglist.emit('select-cursor-row', False)
 
 	def tab_changed(self):
 		self.grab_focus()
@@ -196,7 +196,7 @@ class LogList(gtk.TreeView):
 		liststore = self.get_model()
 		if liststore is None:
 			return None
-		for i in range(len(liststore)):
+		for i in xrange(len(liststore)):
 			liststore[i][self.LISTSTORE_PLAYING] = STATE_BOTTLE_NONE
 
 	def get_bottle_state(self, mid):
@@ -311,7 +311,7 @@ class LogList(gtk.TreeView):
 
 	def get_plain_array(self):
 		lines = []
-		for row in range(self.rows()):
+		for row in xrange(self.rows()):
 			line = []
 
 			for col in [self.LISTSTORE_DATETIME, self.LISTSTORE_GHOST, self.LISTSTORE_CHANNEL,
