@@ -1,4 +1,4 @@
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
 #  logwindow.py - Log window for GBottler
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
@@ -11,46 +11,123 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: logwindow.py,v 1.24 2004/10/11 14:46:27 atzm Exp $
+# $Id: logwindow.py,v 1.36 2005/09/21 12:04:46 atzm Exp $
 #
 
-import gtk
+import gtk, gobject
 import os, time
+#import gc
+#gc.set_debug(gc.DEBUG_LEAK)
 
 from logfetchdialog import LogFetchDialog
 from textmanager    import TextManager
 from logbook        import LogBook
 from loglist        import LogList
 from logmanager     import XMLLogWriter, XMLLogOpener, LogFetchOperator
-from prefs          import PreferenceManager
 
 from common import *
+import config
 
 class LogWindow:
-	def __init__(self, app, prefs):
+	MENU_STRING = '''
+<menubar name="MenuBar">
+    <menu name="File" action="File">
+        <menuitem name="Open" action="Open"/>
+        <menuitem name="Save" action="Save"/>
+        <menuitem name="Download" action="Download"/>
+        <separator/>
+        <menuitem name="Close" action="Close"/>
+    </menu>
+    <menu name="Edit" action="Edit">
+        <menuitem name="CopyTime" action="CopyTime"/>
+        <menuitem name="CopyGhost" action="CopyGhost"/>
+        <menuitem name="CopyChannel" action="CopyChannel"/>
+        <menuitem name="CopyScript" action="CopyScript"/>
+        <menuitem name="CopyAll" action="CopyAll"/>
+        <separator/>
+        <menuitem name="Search" action="Search"/>
+        <separator/>
+        <menuitem name="HideSystemMessage" action="HideSystemMessage"/>
+        <menuitem name="Preferences" action="Preferences"/>
+    </menu>
+    <menu name="Help" action="Help" position="bot">
+        <menuitem name="About" action="About"/>
+    </menu>
+</menubar>
+'''
+	POPUP_MENU_STRING = '''
+<menubar name="PopupMenuBar">
+    <menu name="MainMenu" action="MainMenu">
+        <menuitem name="Play" action="Play"/>
+        <menuitem name="Volley" action="Volley"/>
+        <separator/>
+        <menu name="Cancel" action="Cancel">
+            <menuitem name="CancelPlay" action="CancelPlay"/>
+            <menuitem name="CanselPage" action="CancelPage"/>
+            <menuitem name="CancelAll" action="CancelAll"/>
+        </menu>
+        <separator/>
+        <menuitem name="Vote" action="Vote"/>
+        <menuitem name="Agree" action="Agree"/>
+        <separator/>
+        <menuitem name="CopyTime" action="CopyTime"/>
+        <menuitem name="CopyGhost" action="CopyGhost"/>
+        <menuitem name="CopyChannel" action="CopyChannel"/>
+        <menuitem name="CopyScript" action="CopyScript"/>
+        <menuitem name="CopyAll" action="CopyAll"/>
+    </menu>
+</menubar>
+	'''
+
+	def __init__(self, app):
 # === Definition of Basic Const === #
-		self.app    = app
-		accel_group = gtk.AccelGroup()
-
-		self.logtabpos  = int(prefs.get(PreferenceManager.PREF_POSITION_TAB))
-		self.logpagepos = prefs.get(PreferenceManager.PREF_POSITION_PAGE)
-		self.logtabfocus= prefs.get(PreferenceManager.PREF_FOCUS_TAB)
-
-		self.set_self_msg()
+		self.app = app
 		self.volley_canceler = False
 
+# === Create Menubar === #
+		self.uimanager = gtk.UIManager()
+		self.accel_group = self.uimanager.get_accel_group()
+		self.action_group = gtk.ActionGroup('GBottler')
+		self.action_group.add_actions([
+            ('MenuBar', None, _('_MenuBar')),
+            ('File', None, _('_File')),
+            ('Open', gtk.STOCK_OPEN, _('_Open...'), '<control>o', _('Open XML log'), self.open_xml_log),
+            ('Save', gtk.STOCK_SAVE_AS, _('_Save as...'), '<control>s', _('Save log as XML'), self.save_as_xml),
+            ('Download', gtk.STOCK_CONVERT, _('_Download...'), None, _('Download log from bottle server'), self.fetch),
+            ('Close', gtk.STOCK_CLOSE, _('_Close'), None, _('Close log window'), self.close),
+            ('Edit', None, _('_Edit')),
+            ('CopyTime', None, _('Copy time'), None, _('Copy time from selected bottle'), self.edit_copy_time),
+            ('CopyGhost', None, _('Copy ghostname'), None, _('Copy ghost name from selected bottle'), self.edit_copy_ghostname),
+            ('CopyChannel', None, _('Copy channel'), None, _('Copy channel name from selected bottle'), self.edit_copy_channel),
+            ('CopyScript', gtk.STOCK_COPY, _('Copy script'), '<control>c', _('Copy script from selected bottle'), self.edit_copy_script),
+            ('CopyAll', None, _('Copy all data'), None, _('Copy all data from selected bottle'), self.edit_copy_all),
+            ('Search', gtk.STOCK_FIND, _('Search'), '<control>f', _('Search'), lambda x: self.search_entry.grab_focus()),
+            ('Preferences', gtk.STOCK_PREFERENCES, _('_Preferences...'), '<control>p', _('Edit preferences'), self.app.open_preference),
+            ('Help', None, _('_Help')),
+            ('About', gtk.STOCK_DIALOG_INFO, _('About'), None, _('About GBottler'), self.app.about),
+            ])
+		self.action_group.add_toggle_actions([
+			('HideSystemMessage', None, _('Hide system message'), None, _('Hide system message'),
+			 lambda x: self.msgframe.set_property('visible', not x.get_active()))
+			])
+		self.uimanager.insert_action_group(self.action_group, 0)
+		self.ui_merge_id = self.uimanager.add_ui_from_string(self.MENU_STRING)
+
+		main_menubar = self.uimanager.get_widget('/MenuBar')
+		main_menubar.show()
+
 # === Create Base Window === #
 		self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
-		self.window.add_accel_group(accel_group)
+		self.window.add_accel_group(self.accel_group)
 		self.window.connect("delete_event", self.close)
-		self.window.set_title(unicode(_(APP), "utf-8") + ":" + \
-							  unicode(_("Logs"), "utf-8"))
-		self.window.set_size_request(450,300)
+		self.window.set_title('%s: %s' % (APP, _('Logs')))
+		self.window.set_default_size(config.get('logwindow', 'width', 'int'),
+									 config.get('logwindow', 'height', 'int'))
 
 # === Create Entry for Search === #
 		self.search_entry = gtk.Entry()
 		self.search_entry.show()
-		self.search_entry.set_text(self.msg['search'])
+		self.search_entry.set_text(_('Search'))
 		self.search_entry.connect("activate", self.search)
 		self.search_entry.connect("key-press-event", self.entry_keypress)
 		self.search_entry.connect("focus-in-event", self.set_entry_guide, 'in')
@@ -62,26 +139,24 @@ class LogWindow:
 		self.s_a_b = gtk.ToggleButton()
 		self.s_a_b.show()
 		self.s_a_b.add(self.s_arrow)
-		self.s_a_b.connect('clicked',
-						   lambda x: self.s_arrow.set((not self.s_arrow.get_property('arrow-type')),
-													  gtk.SHADOW_NONE))
+		self.s_a_b.connect('clicked', lambda x: self.s_arrow.set((not self.s_arrow.get_property('arrow-type')), gtk.SHADOW_NONE))
 		self.s_a_b.connect('focus-in-event', lambda x, y: self.search_entry.grab_focus())
 
 		self.sbar = gtk.Statusbar()
 		self.sbar.show()
-		self.sbar.set_has_resize_grip(gtk.TRUE)
+		self.sbar.set_has_resize_grip(True)
 
 		self.rowsbar = gtk.Statusbar()
 		self.rowsbar.show()
-		self.rowsbar.set_has_resize_grip(gtk.FALSE)
+		self.rowsbar.set_has_resize_grip(False)
 
 		self.curr_rowsbar = gtk.Statusbar()
 		self.curr_rowsbar.show()
-		self.curr_rowsbar.set_has_resize_grip(gtk.FALSE)
+		self.curr_rowsbar.set_has_resize_grip(False)
 
 		search_hbox = gtk.HBox()
 		search_hbox.show()
-		search_hbox.pack_start(self.s_a_b, gtk.FALSE, gtk.FALSE, 0)
+		search_hbox.pack_start(self.s_a_b, False, False, 0)
 		search_hbox.pack_start(self.search_entry)
 		search_hbox.pack_start(self.curr_rowsbar)
 		search_hbox.pack_start(self.rowsbar)
@@ -99,7 +174,7 @@ class LogWindow:
 		msgbox = gtk.HBox()
 		msgbox.show()
 		msgbox.pack_start(self.messagebar)
-		msgbox.pack_start(btn, gtk.FALSE)
+		msgbox.pack_start(btn, False)
 
 		self.msgframe = gtk.Frame()
 		self.msgframe.show()
@@ -111,51 +186,42 @@ class LogWindow:
 		bottombox.pack_start(self.msgframe)
 		bottombox.pack_start(search_hbox)
 
-# === Create Menubar === #
-		menu_items = self.get_menu_items()
-		# can't set menu_items before set entry
-
-		self.item_factory = gtk.ItemFactory(gtk.MenuBar, "<main>", accel_group)
-		self.item_factory.create_items(menu_items)
-
-		main_menubar = self.item_factory.get_widget("<main>")
-		main_menubar.show()
-
 # === Create Popup Menu for LogList === #
-		p_menu = (
-			( "/%s" % unicode(_("Play")), "<control>p", self.play, 0, "<StockItem>", gtk.STOCK_REFRESH ),
-			( "/%s" % unicode(_("Volley")), None, self.volley, 0, "<StockItem>", gtk.STOCK_GOTO_TOP ),
-			( '/sep1', None, None, 0, "<Separator>" ),
-			( "/%s" % unicode(_("Cancel to play")), None, None, 0, "<Branch>" ),
-			( "/%s/%s" % (unicode(_("Cancel to play")), unicode(_("This bottle"))),
-			  None, self.cancel_play, 0, "<StockItem>", gtk.STOCK_CANCEL ),
-			( "/%s/%s" % (unicode(_("Cancel to play")), unicode(_("This page"))),
-			  None, self.cancel_play_page, 0, "<StockItem>", gtk.STOCK_CANCEL ),
-			( "/%s/%s" % (unicode(_("Cancel to play")), unicode(_("All"))),
-			  None, self.cancel_play_all, 0, "<StockItem>", gtk.STOCK_CANCEL ),
-			( '/sep2', None, None, 0, "<Separator>" ),
-			( "/%s" % unicode(_("Vote")), "<control><alt>v", self.voting, 0, "<StockItem>", gtk.STOCK_YES ),
-			( "/%s" % unicode(_("Agree")), "<control><alt>a", self.agreeing, 0, "<StockItem>", gtk.STOCK_NO ),
-			( '/sep3', None, None, 0, "<Separator>" ),
-			( "/%s" % self.msg["copy time"], None, self.edit_copy_time, 0, None ),
-			( "/%s" % self.msg["copy ghostname"], None, self.edit_copy_ghostname, 0, None ),
-			( "/%s" % self.msg["copy channel"], None, self.edit_copy_channel, 0, None ),
-			( "/%s" % self.msg["copy script"], "<control>c", self.edit_copy_script, 0, "<StockItem>", gtk.STOCK_COPY ),
-			( "/%s" % self.msg["copy all"], None, self.edit_copy_all, 0, None ),
-			)
-		self.p_ifact = gtk.ItemFactory(gtk.Menu, "<main>", accel_group)
-		self.p_ifact.create_items(p_menu)
-		self.popup_menu = self.p_ifact.get_widget("<main>")
+		self.popup_uimanager = gtk.UIManager()
+		self.popup_accel_group = self.popup_uimanager.get_accel_group()
+		self.popup_action_group = gtk.ActionGroup('GBottler')
+		self.popup_action_group.add_actions([
+            ('PopupMenuBar', None, _('PopupMenuBar')),
+            ('MainMenu', None, _('MainMenu')),
+            ('Play', STATE_BOTTLE_PLAYING, _('Play'), '<control>p', _('Play this bottle'), self.play),
+            ('Volley', gtk.STOCK_MEDIA_FORWARD, _('Volley'), None, _('Volley'), self.volley),
+            ('Cancel', None, _('Cancel')),
+            ('CancelPlay', gtk.STOCK_MEDIA_STOP, _('This bottle'), None, _('Cancel this bottle'), self.cancel_play),
+            ('CancelPage', gtk.STOCK_MEDIA_STOP, _('This page'), None, _('Cancel this page'), self.cancel_play_page),
+            ('CancelAll', gtk.STOCK_MEDIA_STOP, _('All'), None, _('Cancel all bottle'), self.cancel_play_all),
+            ('Vote', gtk.STOCK_YES, _('Vote'), '<control><alt>v', _('Vote this bottle'), self.voting),
+            ('Agree', gtk.STOCK_NO, _('Agree'), '<control><alt>a', _('Agree this bottle'), self.agreeing),
+            ('CopyTime', None, _('Copy time'), None, _('Copy time from selected bottle'), self.edit_copy_time),
+            ('CopyGhost', None, _('Copy ghostname'), None, _('Copy ghost name from selected bottle'), self.edit_copy_ghostname),
+            ('CopyChannel', None, _('Copy channel'), None, _('Copy channel name from selected bottle'), self.edit_copy_channel),
+            ('CopyScript', gtk.STOCK_COPY, _('Copy script'), '<control>c', _('Copy script from selected bottle'), self.edit_copy_script),
+            ('CopyAll', None, _('Copy all data'), None, _('Copy all data from selected bottle'), self.edit_copy_all),
+            ])
+		self.popup_uimanager.insert_action_group(self.popup_action_group, 0)
+		self.popup_ui_merge_id = self.popup_uimanager.add_ui_from_string(self.POPUP_MENU_STRING)
+		self.window.add_accel_group(self.popup_accel_group)
+
+		self.popup_menu = self.popup_uimanager.get_widget('/PopupMenuBar/MainMenu').get_submenu()
 
 		# keep MenuItems, vote and agree
-		self.vi = self.p_ifact.get_item("/%s" % unicode(_("Vote"), "utf-8"))
-		self.ai = self.p_ifact.get_item("/%s" % unicode(_("Agree"), "utf-8"))
+		self.vi = self.popup_uimanager.get_widget('/PopupMenuBar/MainMenu/Vote')
+		self.ai = self.popup_uimanager.get_widget('/PopupMenuBar/MainMenu/Agree')
 
 # === Create Log Viewer === #
-		self.textmanager = TextManager(self, prefs)
+		self.textmanager = TextManager(self)
 		self.textmanager.set_style_talk()
-		self.textmanager.set_cursor_visible(gtk.FALSE)
-		self.textmanager.set_editable(gtk.FALSE)
+		self.textmanager.set_cursor_visible(False)
+		self.textmanager.set_editable(False)
 		self.textmanager.set_border_width(0)
 		self.textmanager.connect("focus-in-event", self.focus_active_loglist)
 		self.textmanager.show()
@@ -177,7 +243,7 @@ class LogWindow:
 		open_button  = get_icon_button(gtk.STOCK_OPEN,    gtk.ICON_SIZE_MENU)
 		save_button  = get_icon_button(gtk.STOCK_SAVE_AS, gtk.ICON_SIZE_MENU)
 
-		self.pb = get_icon_button(gtk.STOCK_REFRESH, gtk.ICON_SIZE_MENU)
+		self.pb = get_icon_button(STATE_BOTTLE_PLAYING, gtk.ICON_SIZE_MENU)
 		self.vb = get_icon_button(gtk.STOCK_YES,     gtk.ICON_SIZE_MENU)
 		self.ab = get_icon_button(gtk.STOCK_NO,      gtk.ICON_SIZE_MENU)
 
@@ -185,61 +251,54 @@ class LogWindow:
 		open_button.connect("clicked", self.open_xml_log)
 		save_button.connect("clicked", self.save_as_xml)
 
-		self.pb.connect("clicked", self.play, None)
-		self.vb.connect("clicked", self.voting, None)
-		self.ab.connect("clicked", self.agreeing, None)
+		self.pb.connect("clicked", self.play)
+		self.vb.connect("clicked", self.voting)
+		self.ab.connect("clicked", self.agreeing)
 
-		self.vb.set_sensitive(gtk.FALSE)
-		self.ab.set_sensitive(gtk.FALSE)
+		self.vb.set_sensitive(False)
+		self.ab.set_sensitive(False)
 
 		for item in [fetch_button, open_button, save_button,
 					 self.pb, self.vb, self.ab]:
 			item.connect("focus-in-event", self.focus_active_loglist)
 
 		self.tooltips = gtk.Tooltips()
-		self.tooltips.set_tip(fetch_button, self.msg['fetch'])
-		self.tooltips.set_tip(open_button, self.msg['open_xml'])
-		self.tooltips.set_tip(save_button, self.msg['save'])
+		self.tooltips.set_tip(fetch_button, _('Download log from bottle server'))
+		self.tooltips.set_tip(open_button, _('Open XML log'))
+		self.tooltips.set_tip(save_button, _('Save log as XML'))
 
-		self.tooltips.set_tip(self.pb, unicode(_("Play"), "utf-8"))
-		self.tooltips.set_tip(self.vb, unicode(_("Vote"), "utf-8"))
-		self.tooltips.set_tip(self.ab, unicode(_("Agree"), "utf-8"))
+		self.tooltips.set_tip(self.pb, _("Play"))
+		self.tooltips.set_tip(self.vb, _("Vote"))
+		self.tooltips.set_tip(self.ab, _("Agree"))
 
 # === Create Labels and style === #
-		style_desc = gtk.Label(unicode(_("Style"), "utf-8") + ": ")
-		style_desc.show()
-
-		self.style_l = gtk.Label(self.msg['talk style'])
-		self.style_l.show()
-
-		self.s_e_box = gtk.EventBox()
-		self.s_e_box.show()
-		self.s_e_box.set_events(gtk.gdk.BUTTON_PRESS_MASK)
-		self.s_e_box.add(self.style_l)
-		self.s_e_box.connect("button-press-event", self.button_popup,
-							 self.item_factory.get_widget("/%s/%s" % (self.msg["view"][1],
-																	  self.msg["style"][1])))
+		self.style_combo = gtk.combo_box_new_text()
+		for text in [_('Talk style'), _('Script style'), _('Script style with linefeed')]:
+			self.style_combo.append_text(text)
+		self.style_combo.set_active(STYLE_TALK)
+		self.style_combo.connect('changed', self.set_style)
+		self.style_combo.show()
 
 # === Bring Buttons and Labels together to HBox, Frame === #
 		toolbox = gtk.HBox()
 		toolbox.show()
 
-		toolbox.pack_start(fetch_button, gtk.FALSE, gtk.TRUE, 0)
-		toolbox.pack_start(open_button, gtk.FALSE, gtk.TRUE, 0)
-		toolbox.pack_start(save_button, gtk.FALSE, gtk.TRUE, 0)
+		toolbox.pack_start(fetch_button, False, True, 0)
+		toolbox.pack_start(open_button, False, True, 0)
+		toolbox.pack_start(save_button, False, True, 0)
 		vs = gtk.VSeparator()
 		vs.show()
-		toolbox.pack_start(vs, gtk.FALSE, gtk.TRUE, 3)
+		toolbox.pack_start(vs, False, True, 3)
 
-		toolbox.pack_start(self.pb, gtk.FALSE, gtk.TRUE, 0)
-		toolbox.pack_start(self.vb, gtk.FALSE, gtk.TRUE, 0)
-		toolbox.pack_start(self.ab, gtk.FALSE, gtk.TRUE, 0)
+		toolbox.pack_start(self.pb, False, True, 0)
+		toolbox.pack_start(self.vb, False, True, 0)
+		toolbox.pack_start(self.ab, False, True, 0)
 		vs = gtk.VSeparator()
 		vs.show()
-		toolbox.pack_start(vs, gtk.FALSE, gtk.TRUE, 3)
+		toolbox.pack_start(vs, False, True, 3)
 
-		toolbox.pack_start(style_desc, gtk.FALSE, gtk.TRUE, 0)
-		toolbox.pack_start(self.s_e_box, gtk.FALSE, gtk.TRUE, 0)
+		#toolbox.pack_start(style_desc, False, True, 0)
+		toolbox.pack_start(self.style_combo, False, True, 0)
 
 		button_frame = gtk.Frame()
 		button_frame.show()
@@ -248,48 +307,50 @@ class LogWindow:
 		button_frame.add(toolbox)
 
 # === Create Notebook === #
-		label = unicode(_('Current'), 'utf-8')
+		label = _('Current')
 		self.logbook = LogBook(label)
-		self.logbook.set_tab_pos(self.logtabpos)
+		self.tab_pos_changed()
 		self.logbook.connect('switch-page', self.tab_changed)
 
 		self.create_tab(label)
 
 # === Bring Log Entry and Log Viewer together to VPaned === #
-		main_paned = gtk.VPaned()
-		main_paned.show()
-		main_paned.pack1(self.logbook, gtk.TRUE)
-		main_paned.pack2(text_frame, gtk.FALSE)
+		self.main_paned = gtk.VPaned()
+		self.main_paned.show()
+		self.main_paned.pack1(self.logbook, True)
+		self.main_paned.pack2(text_frame, False)
+		self.main_paned.set_position(config.get('logwindow', 'paned_position', 'int'))
 
 # === Bring all items together to Main Window Finally === #
-		main_vbox = gtk.VBox(gtk.FALSE, 0)
+		main_vbox = gtk.VBox(False, 0)
 		main_vbox.show()
 
-		main_vbox.pack_start(main_menubar, gtk.FALSE, gtk.TRUE, 0)
-		main_vbox.pack_start(button_frame, gtk.FALSE, gtk.TRUE, 0)
-		main_vbox.pack_start(main_paned)
-		main_vbox.pack_start(bottombox, gtk.FALSE, gtk.FALSE, 0)
-		#main_vbox.pack_start(search_hbox, gtk.FALSE, gtk.FALSE, 0)
+		main_vbox.pack_start(main_menubar, False, True, 0)
+		main_vbox.pack_start(button_frame, False, True, 0)
+		main_vbox.pack_start(self.main_paned)
+		main_vbox.pack_start(bottombox, False, False, 0)
 
 		self.window.add(main_vbox)
 
 # === Initialization of LogWindow === #
+		button = self.uimanager.get_widget('/MenuBar/Edit/HideSystemMessage')
+		button.set_active(config.get('logwindow', 'hide_system_message', 'boolean'))
 		self.focus_active_loglist()
 
-	def open(self, widget, data):
+	def open(self, widget=None, *args):
 		self.window.show()
 
-	def close(self, widget=None, e=None, data=None):
+	def close(self, widget=None, *args):
 		self.window.hide()
-		return gtk.TRUE
+		return True
 
 	def join(self):
 		for item in [self.vb, self.ab, self.vi, self.ai]:
-			item.set_sensitive(gtk.TRUE)
+			item.set_sensitive(True)
 
 	def part(self):
 		for item in [self.vb, self.ab, self.vi, self.ai]:
-			item.set_sensitive(gtk.FALSE)
+			item.set_sensitive(False)
 
 	def set_message(self, text):
 		self.messagebar.set_text(text)
@@ -300,11 +361,11 @@ class LogWindow:
 	def clear_message(self):
 		self.messagebar.set_text('')
 
-	def autologging(self, path, compress=False):
+	def autologging(self):
 		list = self.logbook.get_current_loglist()
 		if not list:
 			return
-		filename = time.strftime(path, time.localtime(time.time()))
+		filename = time.strftime(config.get('logging', 'filename'), time.localtime(time.time()))
 
 		dir = os.path.dirname(filename)
 		if not os.path.exists(dir):
@@ -313,14 +374,22 @@ class LogWindow:
 			except:
 				return
 
-		logger = XMLLogWriter(self, list, filename, compress, False)
+		logger = XMLLogWriter(self, list, filename, config.get('logging', 'gzip', 'boolean'), False)
 		logger.start()
 
 	def save_as_xml(self, widget=None, list=None):
-		filew = CompressFileSelection()
-		filew.set_select_multiple(gtk.FALSE)
+		ffilter = gtk.FileFilter()
+		ffilter.add_pattern('*.xml')
+		ffilter.add_pattern('*.xml.gz')
+		filew = CompressFileChooser(title=_('Log file selection'),
+									parent=self.window,
+									action=gtk.FILE_CHOOSER_ACTION_SAVE,
+									buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+											 gtk.STOCK_OK, gtk.RESPONSE_OK))
+		filew.set_filter(ffilter)
+		filew.set_select_multiple(False)
 		filew.connect("destroy", lambda x: filew.destroy())
-		filew.set_filename(os.path.normpath(open_bottlecase() + '/*.xml'))
+		filew.set_current_folder(os.path.normpath(open_bottlecase()))
 
 		filew.show()
 		while True:
@@ -349,11 +418,19 @@ class LogWindow:
 		logger = XMLLogWriter(self, list, filename, compress, True)
 		logger.start()
 
-	def open_xml_log(self, widget=None, data=None):
-		filew = gtk.FileSelection()
-		filew.set_select_multiple(gtk.FALSE)
+	def open_xml_log(self, widget=None, *args):
+		ffilter = gtk.FileFilter()
+		ffilter.add_pattern('*.xml')
+		ffilter.add_pattern('*.xml.gz')
+		filew = gtk.FileChooserDialog(title=_('Log file selection'),
+									  parent=self.window,
+									  action=gtk.FILE_CHOOSER_ACTION_OPEN,
+									  buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+											   gtk.STOCK_OK, gtk.RESPONSE_OK))
+		filew.set_filter(ffilter)
+		filew.set_select_multiple(False)
 		filew.connect("destroy", lambda x: filew.destroy())
-		filew.set_filename(os.path.normpath(open_bottlecase() + '/*.xml'))
+		filew.set_current_folder(os.path.normpath(open_bottlecase()))
 		filew.show()
 		res = filew.run()
 		filename = filew.get_filename()
@@ -361,12 +438,10 @@ class LogWindow:
 
 		if res == gtk.RESPONSE_OK:
 			if os.path.exists(filename):
-				logger = XMLLogOpener(self, filename,
-									  self.logtabfocus,
-									  self.logpagepos)
+				logger = XMLLogOpener(self, filename)
 				logger.start()
 
-	def fetch(self, widget=None, data=None):
+	def fetch(self, widget=None, *args):
 		try:
 			channels = self.app.client.channels
 		except:
@@ -376,9 +451,7 @@ class LogWindow:
 		if not d.request or not d.request_name:
 			return
 
-		fetcher = LogFetchOperator(self, d.request, d.request_name,
-								   self.logtabfocus,
-								   self.logpagepos)
+		fetcher = LogFetchOperator(self, d.request, d.request_name)
 		fetcher.start()
 
 	def popup_from_logtab(self, widget, event, sender):
@@ -398,15 +471,15 @@ class LogWindow:
 		self.logbook.reorder_child(sender, receiver_n)
 		self.logbook.reorder_child(receiver, sender_n)
 
-	def edit_copy_ghostname(self, widget, data):
+	def edit_copy_ghostname(self, widget=None, data=None):
 		self.edit_copy(widget, data, LogList.LISTSTORE_GHOST)
-	def edit_copy_channel(self, widget, data):
+	def edit_copy_channel(self, widget=None, data=None):
 		self.edit_copy(widget, data, LogList.LISTSTORE_CHANNEL)
-	def edit_copy_script(self, widget, data):
+	def edit_copy_script(self, widget=None, data=None):
 		self.edit_copy(widget, data, LogList.LISTSTORE_SCRIPT)
-	def edit_copy_time(self, widget, data):
+	def edit_copy_time(self, widget=None, data=None):
 		self.edit_copy(widget, data, LogList.LISTSTORE_DATETIME)
-	def edit_copy_all(self, widget, data):
+	def edit_copy_all(self, widget=None, data=None):
 		self.edit_copy(widget, data, LogList.LISTSTORE_ALL)
 	def edit_copy(self, widget, data, target):
 		self.app.dispose_selection()
@@ -426,18 +499,18 @@ class LogWindow:
 		logtab_popup_menu = gtk.Menu()
 		logtab_popup_menu.show()
 
-		save_menuitem = gtk.MenuItem(self.msg["save"])
+		save_menuitem = gtk.MenuItem(_('Save as XML'))
 		save_menuitem.show()
 		save_menuitem.connect("activate", self.save_as_xml, list)
 
-		close_menuitem = gtk.MenuItem(self.msg["close"])
+		close_menuitem = gtk.MenuItem(_('Close'))
 		close_menuitem.show()
 
 		if self.logbook.current_is(list):
 			close_menuitem.connect("activate", self.close_current_tab, child)
 		else:
 			close_menuitem.connect("activate", self.close_tab, child)
-			modify_menuitem = gtk.MenuItem(self.msg["modify tab title"])
+			modify_menuitem = gtk.MenuItem(_('Modify tab title'))
 			modify_menuitem.show()
 			modify_menuitem.connect("activate", self.modify_tab_title, child)
 			logtab_popup_menu.append(modify_menuitem)
@@ -454,8 +527,8 @@ class LogWindow:
 		eventbox.drag_dest_set(gtk.DEST_DEFAULT_MOTION|gtk.DEST_DEFAULT_HIGHLIGHT|gtk.DEST_DEFAULT_DROP,
 							   [ ( "text/plain", 0, 80 ) ], gtk.gdk.ACTION_MOVE)
 
-	def create_tab(self, label_text, pos=None, focus=False, list=None):
-		close_button, eventbox, child = self.logbook.create_tab(label_text, pos, focus, list)
+	def create_tab(self, label_text, list=None):
+		close_button, eventbox, child = self.logbook.create_tab(label_text, list)
 
 		list = child.get_child()
 		self.connect_list(list)
@@ -476,9 +549,7 @@ class LogWindow:
 
 	def update(self, mid, channel, ghost, script, receive_time):
 		datetime = time.strftime("%y/%m/%d %H:%M:%S", receive_time)
-		close_button, eventbox, child = self.logbook.update(mid, channel, ghost, script, datetime,
-															pos=self.logpagepos,
-															focus=self.logtabfocus)
+		close_button, eventbox, child = self.logbook.update(mid, channel, ghost, script, datetime)
 
 		if child and close_button and eventbox:
 			# if Tab named `Current' Created
@@ -501,10 +572,12 @@ class LogWindow:
 		self.focus_active_loglist()
 
 	def close_current_tab(self, widget, child):
-		self.app.notify_log_current_tab_closed()
+		if config.get('logging', 'save_current_when_close_tab', 'boolean'):
+			self.autologging()
 		self.close_tab(widget, child)
 
 	def close_tab(self, widget, child):
+		tablabel = self.logbook.get_tab_label(child)
 		n = self.logbook.close_tab(widget, child)
 		if n == -1:
 			self.remove_status()
@@ -513,6 +586,11 @@ class LogWindow:
 		list = child.get_children()[0]
 		self.app.notify_play_cancel_page_of(list)
 
+		tablabel.destroy()
+		#list.destroy()
+		#child.destroy()
+		#gc.collect()
+
 	def connect_list(self, list):
 		list.connect("select-cursor-row",  self.select)
 		list.connect("key-press-event",    self.loglist_keypress)
@@ -527,13 +605,13 @@ class LogWindow:
 	def update_rows(self, list):
 		if list and list.rows():
 			self.rowsbar.pop(0)
-			self.rowsbar.push(0, str(list.rows()) + unicode(_('Messages'), 'utf-8'))
+			self.rowsbar.push(0, str(list.rows()) + _('Items'))
 		self.update_select_no(list)
 
 	def update_select_no(self, list):
 		if list and list.is_selected():
 			self.curr_rowsbar.pop(0)
-			self.curr_rowsbar.push(0, unicode('No.' + str(list.selection()+1), 'utf-8'))
+			self.curr_rowsbar.push(0, 'No.' + str(list.selection()+1))
 
 	def tab_changed(self, notebook, page, pagenum):
 		list = self.logbook.tab_changed(notebook, page, pagenum)
@@ -554,16 +632,16 @@ class LogWindow:
 			return
 
 		self.volley_canceler = False
-		gtk.timeout_add(WAIT_NEXT_REQUEST, self._volley, widget, data, list, list.selection(), 0)
+		gobject.timeout_add(WAIT_NEXT_REQUEST, self._volley, widget, data, list, list.selection(), 0)
 
 	VOLLEY_INTERVAL = 500 # 0.5 sec
 	def _volley(self, widget, data, list, target, min):
 		if self.volley_canceler:
 			self.volley_canceler = False
 			return
-		gtk.timeout_add(WAIT_NEXT_REQUEST, self.play, widget, data, list, target)
+		gobject.timeout_add(WAIT_NEXT_REQUEST, self.play, widget, data, list, target)
 		if target > min:
-			gtk.timeout_add(self.VOLLEY_INTERVAL, self._volley, widget, data, list, target-1, min)
+			gobject.timeout_add(self.VOLLEY_INTERVAL, self._volley, widget, data, list, target-1, min)
 
 	def play(self, widget=None, data=None, list=None, target=None):
 		if list is None or target is None:
@@ -621,30 +699,30 @@ class LogWindow:
 	def log_votes(self, mid, type, num):
 		self.logbook.log_votes(mid, type, num)
 
-	def voting(self, widget, data):
+	def voting(self, widget=None, data=None):
 		mid, type = self.logbook.voting(widget, data, self.window)
 		if mid is None or type is None:
 			return
 
 		self.app.vote_message(mid, type)
 
-	def agreeing(self, widget, data):
+	def agreeing(self, widget=None, data=None):
 		mid, type = self.logbook.agreeing(widget, data, self.window)
 		if mid is None or type is None:
 			return
 		self.app.vote_message(mid, type)
 
-	def button_popup(self, widget, event, sender):
-		if event.button in [1, 3]:
-			sender.popup(None, widget, None, event.button, event.time)
+	#def button_popup(self, widget, event, sender):
+	#	if event.button in [1, 3]:
+	#		sender.popup(None, widget, None, event.button, event.time)
 
 	def set_entry_guide(self, widget, event, data):
 		if data == 'in':
-			if widget.get_text() == self.msg['search']:
+			if widget.get_text() == _('Search'):
 				widget.set_text('')
 		elif data == 'out':
 			if not widget.get_text():
-				widget.set_text(self.msg['search'])
+				widget.set_text(_('Search'))
 
 	def popup(self, loglist, event):
 		if event.button == 3:
@@ -652,12 +730,12 @@ class LogWindow:
 		elif event.type == 5:
 			self.play(loglist, event)
 
-	def select(self, loglist, se=gtk.FALSE):
+	def select(self, loglist, se=False):
 		self.textmanager.clear()
 		row = loglist.selection()
 		script = unicode(loglist.get_text(row, LogList.LISTSTORE_SCRIPT), "utf-8", 'replace')
 		self.textmanager.insert_with_color_from(script)
-		self.sw2.emit('scroll-child', gtk.SCROLL_START, gtk.FALSE)
+		self.sw2.emit('scroll-child', gtk.SCROLL_START, False)
 		self.sbar.pop(0)
 		self.sbar.push(0, str(len(script.encode('sjis'))) + unicode(_('bytes'), 'utf-8'))
 		self.update_select_no(loglist)
@@ -665,177 +743,91 @@ class LogWindow:
 	def scroll(self, widget, event):
 		if event.state == 1: # shift
 			if event.keyval == 65362: # up
-				self.sw2.emit('scroll-child', gtk.SCROLL_PAGE_UP, gtk.FALSE)
-				return gtk.TRUE
+				self.sw2.emit('scroll-child', gtk.SCROLL_PAGE_UP, False)
+				return True
 			elif event.keyval == 65364: # down
-				self.sw2.emit('scroll-child', gtk.SCROLL_PAGE_DOWN, gtk.FALSE)
-				return gtk.TRUE
-			return gtk.FALSE
-		return gtk.FALSE
+				self.sw2.emit('scroll-child', gtk.SCROLL_PAGE_DOWN, False)
+				return True
+			return False
+		return False
 
 	def entry_keypress(self, widget, event):
 		return self.scroll(widget, event)
 
 	def loglist_keypress(self, widget, event):
-		if self.scroll(widget, event) == gtk.FALSE:
+		if self.scroll(widget, event) == False:
 			if event.keyval == 65293: # enter
 				self.play()
-				return gtk.TRUE
-			return gtk.FALSE
-		return gtk.TRUE
+				return True
+			return False
+		return True
 
-	def set_style(self, data, widget):
-		if data == STYLE_TALK:
-			label = self.msg['talk style']
-		elif data == STYLE_SCRIPT:
-			label = self.msg['script style']
-		elif data == STYLE_SCRIPT_WITH_LINEFEED:
-			label = "%s(%s)" % (self.msg['script style'], self.msg['linefeed'])
-
-		if label == self.style_l.get_text():
-			return
-		self.style_l.set_text(label)
+	def set_style(self, widget=None, *args):
+		data = self.style_combo.get_active()
 		self.textmanager.set_style(data)
 
-		list = self.logbook.get_active_loglist()
-		if not list or not list.is_selected():
+		llist = self.logbook.get_active_loglist()
+		if not llist or not llist.is_selected():
 			return
-		self.select(list)
+		self.select(llist)
 
 	def focus_active_loglist(self, widget=None, data=None):
 		self.logbook.focus_active_loglist()
 
-	def check_message_bar(self, data=None, widget=None):
-		if widget.get_active():
-			self.msgframe.hide()
-		else:
-			self.msgframe.show()
+	#def check_message_bar(self, data=None, widget=None):
+	#	if widget.get_active():
+	#		self.msgframe.hide()
+	#	else:
+	#		self.msgframe.show()
 
 	### notify preference changed start
-	def tab_pos_changed(self, pos):
-		if self.logbook.get_tab_pos() != pos:
-			self.logbook.set_tab_pos(pos)
-			self.logtabpos = pos
+	def tab_pos_changed(self):
+		pos = config.get('logwindow', 'tab_placement', 'int')
+		if pos == config.LOGWINDOW_TAB_PLACEMENT_TOP:
+			gtk_pos = gtk.POS_TOP
+		elif pos == config.LOGWINDOW_TAB_PLACEMENT_BOTTOM:
+			gtk_pos = gtk.POS_BOTTOM
+		elif pos == config.LOGWINDOW_TAB_PLACEMENT_LEFT:
+			gtk_pos = gtk.POS_LEFT
+		else:
+			gtk_pos = gtk.POS_RIGHT
+		self.logbook.set_tab_pos(gtk_pos)
 
-	def color_changed(self, script, sakura, kero, sync, error, URL):
-		self.textmanager.color_changed(script, sakura, kero, sync, error, URL)
+	def color_changed(self):
+		self.textmanager.color_changed()
 		list = self.logbook.get_active_loglist()
 		if not list or not list.is_selected():
 			return
 		self.select(list)
 
-	def font_changed(self, genfont, scfont):
-		self.textmanager.font_changed(genfont, scfont)
+	def font_changed(self):
+		self.textmanager.font_changed()
 
-	def browser_changed(self, browser):
-		self.textmanager.browser_changed(browser)
-
-	def page_pos_changed(self, pos):
-		self.logpagepos = pos
-
-	def log_tab_focus_changed(self, focus):
-		self.logtabfocus = focus
-
-	def receive_preferences_changed(self, prefs):
-		self.tab_pos_changed(int(prefs[PreferenceManager.PREF_POSITION_TAB]))
-		self.page_pos_changed(prefs[PreferenceManager.PREF_POSITION_PAGE])
-		self.log_tab_focus_changed(prefs[PreferenceManager.PREF_FOCUS_TAB])
-		self.color_changed(prefs[PreferenceManager.PREF_COLOR_SCRIPT],
-						   prefs[PreferenceManager.PREF_COLOR_SAKURA],
-						   prefs[PreferenceManager.PREF_COLOR_KERO],
-						   prefs[PreferenceManager.PREF_COLOR_SYNCHRONIZED],
-						   prefs[PreferenceManager.PREF_COLOR_ERROR],
-						   prefs[PreferenceManager.PREF_COLOR_URL])
-		self.font_changed(prefs[PreferenceManager.PREF_FONT_GENERAL],
-						  prefs[PreferenceManager.PREF_FONT_SCRIPT])
-		self.browser_changed(prefs[PreferenceManager.PREF_BROWSER_COMMAND])
+	def receive_preferences_changed(self):
+		self.color_changed()
+		self.font_changed()
+		self.tab_pos_changed()
 	### notify preference changed end
 
-	def help(self, event=None):
-		pass
+	def generate_ghost_list(self):
+		glist = []
 
-	def get_menu_items(self):
-		menu_items = (
-			( "/%s" % self.app.msg["file"][0], None, None, 0, "<Branch>" ),
-			( "/%s/%s..." % (self.app.msg["file"][1], self.msg["open_xml"]), "<control>o", self.open_xml_log,
-			  0, "<StockItem>", gtk.STOCK_OPEN ),
-			( "/%s/%s..." % (self.app.msg["file"][1], self.msg["save"]), "<control>s", self.save_as_xml,
-			  0, "<StockItem>", gtk.STOCK_SAVE_AS ),
-			( "/%s/%s..." % (self.app.msg["file"][1], self.msg["fetch"]), None, self.fetch,
-			  0, "<StockItem>", gtk.STOCK_CONVERT ),
-			( "/%s/%s" % (self.app.msg["file"][1], self.msg["close"]), "<control>q", self.close,
-			  0, "<StockItem>", gtk.STOCK_CLOSE ),
+		for gname in self.app.uniq_ghosts():
+			if gname not in glist:
+				glist.append(gname)
 
-			( "/%s" % self.app.msg["edit"][0], None, None, 0, "<Branch>" ),
-			( "/%s/%s" % (self.app.msg["edit"][1], self.msg["copy time"]),
-			  None, self.edit_copy_time, 0, None ),
-			( "/%s/%s" % (self.app.msg["edit"][1], self.msg["copy ghostname"]),
-			  None, self.edit_copy_ghostname, 0, None ),
-			( "/%s/%s" % (self.app.msg["edit"][1], self.msg["copy channel"]),
-			  None, self.edit_copy_channel, 0, None ),
-			( "/%s/%s" % (self.app.msg["edit"][1], self.msg["copy script"]),
-			  "<control>c", self.edit_copy_script, 0, "<StockItem>", gtk.STOCK_COPY ),
-			( "/%s/%s" % (self.app.msg["edit"][1], self.msg["copy all"]),
-			  None, self.edit_copy_all, 0, None ),
-			( "/%s/sep1" % self.app.msg["edit"][1], None, None, 0, "<Separator>" ),
-			( "/%s/%s" % (self.app.msg["edit"][1], self.msg["search"]), "<control>f",
-			  lambda x, y: self.search_entry.grab_focus(), 0, "<StockItem>", gtk.STOCK_FIND ),
-			( "/%s/sep2" % self.app.msg["edit"][1], None, None, 0, "<Separator>" ),
-			( "/%s/%s..." % (self.app.msg["edit"][1], self.app.msg["pref"][0]), None,
-			  self.app.open_preference, 0, "<StockItem>", gtk.STOCK_PREFERENCES ),
+		for n in xrange(self.logbook.get_n_pages()):
+			loglist = self.logbook.get_nth_page(n).get_child()
+			for r in xrange(loglist.rows()):
+				gname = loglist.get_text(r, loglist.LISTSTORE_GHOST)
+				if gname not in glist:
+					glist.append(gname)
 
-			( "/%s" % self.msg["view"][0], None, None, 0, "<Branch>" ),
+		return glist
 
-			( "/%s/%s" % (self.msg["view"][1], self.msg["style"][0]), None, None, 0, "<Branch>" ),
-			( "/%s/%s/%s" % (self.msg["view"][1], self.msg["style"][1], self.msg["talk style"]),
-			  None, self.set_style, STYLE_TALK, "<RadioItem>" ),
-			( "/%s/%s/%s" % (self.msg["view"][1], self.msg["style"][1], self.msg["script style"]),
-			  None, self.set_style, STYLE_SCRIPT,
-			  "/%s/%s/%s" % (self.msg["view"][1],
-							 self.msg["style"][1],
-							 self.msg["talk style"])),
-			( "/%s/%s/%s(%s)" % (self.msg["view"][1], self.msg["style"][1],
-								 self.msg["script style"], self.msg["linefeed"]),
-			  None, self.set_style, STYLE_SCRIPT_WITH_LINEFEED,
-			  "/%s/%s/%s" % (self.msg["view"][1],
-							 self.msg["style"][1],
-							 self.msg["script style"])),
-			( "/%s/%s" % (self.msg["view"][1], self.msg["hide_msg"]), None, self.check_message_bar, 0, "<CheckItem>" ),
-
-			( "/%s" % self.app.msg["help"][0], None, None, 0, "<LastBranch>" ),
-			( "/%s/%s..." % (self.app.msg["help"][1], self.app.msg["about"]), None, self.app.about,
-			  0, "<StockItem>", gtk.STOCK_DIALOG_INFO ),
-			)
-		return menu_items
-
-	def set_self_msg(self):
-		self.msg = {
-			"open_xml":  unicode(_("Open XML log"), "utf-8"),
-			"save":  unicode(_("Save as XML"), "utf-8"),
-			"fetch":  unicode(_("Fetch logs"), "utf-8"),
-			"close":  unicode(_("Close"), "utf-8"),
-			"modify tab title":  unicode(_("Modify tab title"), "utf-8"),
-			"copy script":   unicode(_("Copy script"), "utf-8"),
-			"copy ghostname": unicode(_("Copy ghost name"), "utf-8"),
-			"copy channel":   unicode(_("Copy channel"), "utf-8"),
-			"copy time":   unicode(_("Copy time"), "utf-8"),
-			"copy all":   unicode(_("Copy all"), "utf-8"),
-			"search":   unicode(_("Search"), "utf-8"),
-
-			"view":		   [unicode(_("View(_V)"), "utf-8"),
-							unicode(_("View(V)"), "utf-8")],
-			"update":	   unicode(_("Update"), "utf-8"),
-			"style":	   [unicode(_("Style(_S)"), "utf-8"),
-							unicode(_("Style(S)"), "utf-8")],
-			"hide_msg":    unicode(_("Hide system messages"), "utf-8"),
-			"talk style":  unicode(_("Talk style"), "utf-8"),
-			"script style":unicode(_("Script style"), "utf-8"),
-			"linefeed":	   unicode(_("with linefeed"), "utf-8"),
-			}
-
-class CompressFileSelection(gtk.FileSelection):
-	def __init__(self):
-		gtk.FileSelection.__init__(self)
+class CompressFileChooser(gtk.FileChooserDialog):
+	def __init__(self, title='', parent=None, action=gtk.FILE_CHOOSER_ACTION_OPEN, buttons=None, backend=''):
+		gtk.FileChooserDialog.__init__(self, title, parent, action, buttons, backend)
 		self.compress = gtk.CheckButton(unicode(_('GZIP Compress'), 'utf-8'))
 		self.compress.show()
-		self.main_vbox.pack_end(self.compress)
+		self.vbox.pack_start(self.compress, False, False)
