@@ -10,7 +10,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: queryluid.py,v 1.7 2004/09/29 21:58:11 atzm Exp $
+# $Id: queryluid.py,v 1.9 2005/09/08 15:44:15 atzm Exp $
 #
 
 import sys, os, string
@@ -74,18 +74,18 @@ class LUIDParser(htmllib.HTMLParser):
 
 	def format(self):
 		length = len(self.result[0])
-		formatted = [[] for i in range(length)]
+		formatted = [[] for i in xrange(length)]
 		for line in self.result:
 			if line[1:]:
-				for i in range(length):
+				for i in xrange(length):
 					formatted[i].append(line[i])
 		self.result = formatted
 
 		length = len(self.headres[0])
-		formatted = [[] for i in range(length)]
+		formatted = [[] for i in xrange(length)]
 		for line in self.headres:
 			if line[1:]:
-				for i in range(length):
+				for i in xrange(length):
 					formatted[i].append(line[i])
 		self.headres = formatted
 
@@ -110,6 +110,11 @@ class LUIDInfo:
 		self.parser = LUIDParser()
 		self.cache  = LUIDCacheManager()
 
+	def set_luid(self, luid):
+		self.luid = luid
+	def get_luid(self):
+		return self.luid
+
 	def get_html(self):
 		try:
 			con = httplib.HTTPConnection(HOST)
@@ -135,7 +140,7 @@ class LUIDInfo:
 			self.cache.save_database()
 
 	def get_all(self, refresh=False):
-		if refresh:
+		if refresh and self.luid:
 			self.parse()
 		return self.cache.get_luid_data()
 
@@ -164,8 +169,10 @@ class LUIDCacheManager:
 	def get_luid_data(self, key=None):
 		if key == None:
 			return self.luid_data
-		if self.luid_data.has_key(key):
+		try:
 			return self.luid_data[key]
+		except KeyError:
+			return []
 
 	def load_database(self):
 		try:
@@ -208,7 +215,7 @@ class LUIDCacheManager:
 		for key in self.luid_data.keys():
 			file.write("[%s]\n" % key)
 			for line in self.luid_data[key]:
-				for i in range(len(line)):
+				for i in xrange(len(line)):
 					file.write(line[i].encode('utf-8'))
 					if i == len(line)-1:
 						file.write("\n")
