@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: script.py,v 1.2 2004/04/19 12:43:44 atzm Exp $
+# $Id: script.py,v 1.3 2005/08/29 19:03:24 atzm Exp $
 #
 
 import re
@@ -379,7 +379,7 @@ def print_script_tree(tree):
         if node[0] == SCRIPT_TAG:
             name, args = node[1], node[2:]
             print "TAG", name
-            for n in range(len(args)):
+            for n in xrange(len(args)):
                 if type(args[n]) == type(''):
                     print "\tARG#%d\t%s" % (n+1, args[n])
                 else:
@@ -396,7 +396,7 @@ def print_text(text, indent):
         elif chunk[0] == TEXT_META:
             name, args = chunk[1], chunk[2:]
             print "\t" * indent + "META\t" + name
-            for n in range(len(args)):
+            for n in xrange(len(args)):
                 print "\t" * indent + "\tARG#%d\t%s" % (n+1, args[n])
 
 if __name__ == "__main__":
