@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: scriptchecker.py,v 1.2 2004/11/16 23:39:51 atzm Exp $
+# $Id: scriptchecker.py,v 1.3 2005/03/11 06:23:27 atzm Exp $
 #
 
 import gtk
@@ -49,8 +49,8 @@ class ScriptChecker:
 			return self.parser.parse(script)
 		except ParserError, e:
 			t = gtk.TextView()
-			t.set_cursor_visible(gtk.FALSE)
-			t.set_editable(gtk.FALSE)
+			t.set_cursor_visible(False)
+			t.set_editable(False)
 			t.set_wrap_mode(gtk.WRAP_CHAR)
 
 			b = t.get_buffer()
