@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: svgmanager.py,v 1.43 2004/10/28 20:52:54 atzm Exp $
+# $Id: svgmanager.py,v 1.47 2005/09/08 21:19:57 atzm Exp $
 
 import gtk, gobject
 import os, sys, shutil
@@ -20,12 +20,12 @@ import string, re
 from showingsurface      import ShowingSurface
 from common              import *
 from viewer.viewercommon import *
+import config
 
 class SVGManagerWindow(gtk.Window):
-	def __init__(self, app, browse_command, ghostmanager):
+	def __init__(self, app, ghostmanager):
 		self.app = app
-		self.browse_command = browse_command
-		self.ghostmanager   = ghostmanager
+		self.ghostmanager = ghostmanager
 
 		accel_group = gtk.AccelGroup()
 
@@ -36,10 +36,10 @@ class SVGManagerWindow(gtk.Window):
 									gobject.TYPE_STRING,  gobject.TYPE_STRING)
 
 		self.ghost_list = gtk.TreeView(self.ghost_list_str)
-		self.ghost_list.set_enable_search(gtk.TRUE)
-		self.ghost_list.set_rules_hint(gtk.TRUE)
-		self.ghost_list.set_search_column(gtk.TRUE)
-		self.ghost_list.set_reorderable(gtk.TRUE)
+		self.ghost_list.set_enable_search(True)
+		self.ghost_list.set_rules_hint(True)
+		self.ghost_list.set_search_column(True)
+		self.ghost_list.set_reorderable(True)
 		self.ghost_list.connect("cursor-changed", self.cursor_changed)
 		self.ghost_list.connect("select-cursor-row", self.select_row)
 
@@ -52,20 +52,20 @@ class SVGManagerWindow(gtk.Window):
 			gtk.TreeViewColumn(unicode(_('FMO'), 'utf-8')),
 			gtk.TreeViewColumn(unicode(_('Path'), 'utf-8')),
 			]
-		for i in range(len(columns)):
-			columns[i].set_resizable(gtk.TRUE)
-			columns[i].set_clickable(gtk.TRUE)
+		for i in xrange(len(columns)):
+			columns[i].set_resizable(True)
+			columns[i].set_clickable(True)
 			columns[i].connect("clicked", self.sort, i)
 			self.ghost_list.append_column(columns[i])
 
 			if i == 0:
 				cell = gtk.CellRendererToggle()
 				cell.connect("toggled", self.check_use_toggle)
-				columns[i].pack_start(cell, gtk.TRUE)
+				columns[i].pack_start(cell, True)
 				columns[i].add_attribute(cell, 'active', i)
 			else:
 				cell = gtk.CellRendererText()
-				columns[i].pack_start(cell, gtk.TRUE)
+				columns[i].pack_start(cell, True)
 				columns[i].add_attribute(cell, 'text', i)
 				if   i == 1: cell.set_property('width', 80)
 				elif i == 2: cell.set_property('width', 40)
@@ -93,14 +93,14 @@ class SVGManagerWindow(gtk.Window):
 		unyuu_f.add(self.unyuu_box)
 
 		#info_ghost is 'showing surface [0] and [10]'
-		info_ghost = gtk.HBox(gtk.FALSE)
-		info_ghost.pack_start(unyuu_f, gtk.TRUE, gtk.FALSE, 0)
-		info_ghost.pack_start(sakura_f, gtk.TRUE, gtk.FALSE, 0)
+		info_ghost = gtk.HBox(False)
+		info_ghost.pack_start(unyuu_f, True, False, 0)
+		info_ghost.pack_start(sakura_f, True, False, 0)
 
 		self.button_id = None
 		self.url_button = get_icon_button(gtk.STOCK_JUMP_TO, size=gtk.ICON_SIZE_BUTTON,
 										  relief=gtk.RELIEF_NORMAL, label=unicode(_('URL'), 'utf-8'))
-		self.url_button.set_sensitive(gtk.FALSE)
+		self.url_button.set_sensitive(False)
 		self.url_button.add_accelerator("clicked",  accel_group, ord('J'),
 										gtk.gdk.CONTROL_MASK|gtk.gdk.MOD1_MASK,
 										gtk.ACCEL_VISIBLE)
@@ -108,33 +108,33 @@ class SVGManagerWindow(gtk.Window):
 		self.button_id_s = None
 		self.sur_button = get_icon_button(gtk.STOCK_INDEX, size=gtk.ICON_SIZE_BUTTON,
 										  relief=gtk.RELIEF_NORMAL, label=unicode(_('Surface'), 'utf-8'))
-		self.sur_button.set_sensitive(gtk.FALSE)
+		self.sur_button.set_sensitive(False)
 		self.sur_button.add_accelerator("clicked",  accel_group, ord('S'),
 										gtk.gdk.CONTROL_MASK|gtk.gdk.MOD1_MASK,
 										gtk.ACCEL_VISIBLE)
 
-		buttonbox = gtk.HBox(gtk.TRUE)
-		buttonbox.pack_start(self.url_button, gtk.FALSE, gtk.FALSE, 0)
-		buttonbox.pack_start(self.sur_button, gtk.FALSE, gtk.FALSE, 0)
+		buttonbox = gtk.HBox(True)
+		buttonbox.pack_start(self.url_button, False, False, 0)
+		buttonbox.pack_start(self.sur_button, False, False, 0)
 
-		info_ghost_a = gtk.VBox(gtk.FALSE)
-		info_ghost_a.pack_start(info_ghost, gtk.TRUE, gtk.FALSE, 0)
-		info_ghost_a.pack_start(buttonbox, gtk.FALSE, gtk.FALSE, 0)
+		info_ghost_a = gtk.VBox(False)
+		info_ghost_a.pack_start(info_ghost, True, False, 0)
+		info_ghost_a.pack_start(buttonbox, False, False, 0)
 
 		## Showing Ghost Status from svg.txt
 		self.info_svg_str = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
 		info_svg = gtk.TreeView(self.info_svg_str)
-		info_svg.set_headers_visible(gtk.FALSE)
-		info_svg.set_rules_hint(gtk.TRUE)
+		info_svg.set_headers_visible(False)
+		info_svg.set_rules_hint(True)
 
 		svg_cols = [
 			gtk.TreeViewColumn(),
 			gtk.TreeViewColumn(unicode(_('Ghost Status'), 'utf-8'))
 			]
-		for i in range(len(svg_cols)):
+		for i in xrange(len(svg_cols)):
 			info_svg.append_column(svg_cols[i])
 			cell = gtk.CellRendererText()
-			svg_cols[i].pack_start(cell, gtk.TRUE)
+			svg_cols[i].pack_start(cell, True)
 			svg_cols[i].add_attribute(cell, 'text', i)
 
 		isv = gtk.ScrolledWindow()
@@ -144,15 +144,15 @@ class SVGManagerWindow(gtk.Window):
 		isv.add(info_svg)
 
 		info_hbox = gtk.HBox()
-		info_hbox.pack_start(info_ghost_a, gtk.FALSE, gtk.FALSE, 0)
-		info_hbox.pack_start(isv, gtk.TRUE, gtk.TRUE, 0)
+		info_hbox.pack_start(info_ghost_a, False, False, 0)
+		info_hbox.pack_start(isv, True, True, 0)
 
 		v_paned = gtk.VPaned()
 		v_paned.pack1(info_hbox)
 		v_paned.pack2(self.sw)
 
 		self.ghost_name = gtk.Entry()
-		self.ghost_name.set_editable(gtk.FALSE)
+		self.ghost_name.set_editable(False)
 
 		# Create Search Entry
 		self.msg = unicode(_("Search"), "utf-8")
@@ -173,16 +173,16 @@ class SVGManagerWindow(gtk.Window):
 		search_allow_button.connect('focus-in-event', lambda x, y: self.search_entry.grab_focus())
 
 		search_box = gtk.HBox()
-		search_box.pack_start(search_allow_button, gtk.FALSE, gtk.TRUE, 0)
+		search_box.pack_start(search_allow_button, False, True, 0)
 		search_box.pack_start(self.search_entry)
 
-		status_vbox = gtk.VBox(gtk.FALSE, 0)
-		status_vbox.pack_start(self.ghost_name, gtk.FALSE, gtk.FALSE, 0)
-		status_vbox.pack_start(v_paned, gtk.TRUE, gtk.TRUE, 5)
-		status_vbox.pack_start(search_box, gtk.FALSE, gtk.FALSE, 0)
+		status_vbox = gtk.VBox(False, 0)
+		status_vbox.pack_start(self.ghost_name, False, False, 0)
+		status_vbox.pack_start(v_paned, True, True, 5)
+		status_vbox.pack_start(search_box, False, False, 0)
 
 ## Create Bottons (right) window
-		ctrl_vbox = gtk.VBox(gtk.FALSE, 0)
+		ctrl_vbox = gtk.VBox(False, 0)
 		for item in [
 			[gtk.STOCK_ADD,     unicode(_('Add'),    'utf-8'), self.add_ghost,    None],
 			[gtk.STOCK_YES,     unicode(_('FMO'),    'utf-8'), self.check_fmo,    None],
@@ -198,17 +198,18 @@ class SVGManagerWindow(gtk.Window):
 			if item[3] is not None:
 				btn.add_accelerator('clicked', accel_group, item[3][0], item[3][1], gtk.ACCEL_VISIBLE)
 
-			ctrl_vbox.pack_start(btn, gtk.TRUE, gtk.TRUE, 5)
+			ctrl_vbox.pack_start(btn, True, True, 5)
 
-		main_hbox = gtk.HBox(gtk.FALSE, 0)
-		main_hbox.pack_start(status_vbox, gtk.TRUE, gtk.TRUE, 0)
-		main_hbox.pack_start(ctrl_vbox, gtk.FALSE, gtk.FALSE, 5)
+		main_hbox = gtk.HBox(False, 0)
+		main_hbox.pack_start(status_vbox, True, True, 0)
+		main_hbox.pack_start(ctrl_vbox, False, False, 5)
 
 ## Create Base Window
 		gtk.Window.__init__(self, gtk.WINDOW_TOPLEVEL)
 		self.connect("delete-event", self.close)
-		self.set_title(unicode(_(APP), "utf-8") + ": " + unicode(_("SVGManager"), "utf-8"))
-		self.set_default_size(450, 450)
+		self.set_title(unicode(APP, "utf-8") + ": " + unicode(_("SVGManager"), "utf-8"))
+		self.set_default_size(config.get('svgmanager', 'width', 'int'),
+							  config.get('svgmanager', 'height', 'int'))
 		self.add_accel_group(accel_group)
 		self.add(main_hbox)
 		self.clear_info()
@@ -219,10 +220,7 @@ class SVGManagerWindow(gtk.Window):
 
 	def close(self, widget=None, event=None, data=None):
 		self.hide()
-		return gtk.TRUE
-
-	def browser_changed(self, browser):
-		self.browse_command = browser
+		return True
 
 	def sort(self, treeviewcol, col_num):
 		id = self.ghost_list_str.get_sort_column_id()
@@ -245,7 +243,7 @@ class SVGManagerWindow(gtk.Window):
 			rng = range(current+1, len(self.ghost_list_str))
 
 		for i in rng:
-			for j in range(1, 3):
+			for j in xrange(1, 3):
 				m = pat.search(self.ghost_list_str.get_value(self.ghost_list_str.get_iter(i), j))
 				if m:
 					self.ghost_list.set_cursor(i)
@@ -284,17 +282,17 @@ class SVGManagerWindow(gtk.Window):
 	def scroll(self, widget, event):
 		if event.state == 1: # shift
 			if event.keyval == 65362: # up
-				self.sw.emit('scroll-child', gtk.SCROLL_PAGE_UP, gtk.FALSE)
-				return gtk.TRUE
+				self.sw.emit('scroll-child', gtk.SCROLL_PAGE_UP, False)
+				return True
 			elif event.keyval == 65364: # down
-				self.sw.emit('scroll-child', gtk.SCROLL_PAGE_DOWN, gtk.FALSE)
-				return gtk.TRUE
-			return gtk.FALSE
-		return gtk.FALSE
+				self.sw.emit('scroll-child', gtk.SCROLL_PAGE_DOWN, False)
+				return True
+			return False
+		return False
 
 ## 'cursor-changed' signal gtk.TreeView
 	def cursor_changed(self, treeview):
-		treeview.emit("select-cursor-row", gtk.FALSE)
+		treeview.emit("select-cursor-row", False)
 
 	def set_info(self, ghost_name='', sakura='', unyu='', craftman='', hpname='', hpurl='', supported='',
 				 action='', text_path='', surface_path='', version='', info=''):
@@ -318,19 +316,19 @@ class SVGManagerWindow(gtk.Window):
 		self.ghost_name.set_text(ghost_name)
 
 	def clear_info(self):
-		self.sur_button.set_sensitive(gtk.FALSE)
-		self.url_button.set_sensitive(gtk.FALSE)
+		self.sur_button.set_sensitive(False)
+		self.url_button.set_sensitive(False)
 		self.sakura_box.set_from_pixbuf(gtk.gdk.pixbuf_new_from_xpm_data(XPM_VANISH))
 		self.unyuu_box.set_from_pixbuf(gtk.gdk.pixbuf_new_from_xpm_data(XPM_VANISH))
 		self.set_info()
 		self.disconnect_buttons()
 
 	def error_info(self, txt_path):
-		self.sur_button.set_sensitive(gtk.FALSE)
-		self.url_button.set_sensitive(gtk.FALSE)
+		self.sur_button.set_sensitive(False)
+		self.url_button.set_sensitive(False)
 		self.sakura_box.set_from_stock(gtk.STOCK_MISSING_IMAGE, gtk.ICON_SIZE_LARGE_TOOLBAR)
 		self.unyuu_box.set_from_stock(gtk.STOCK_MISSING_IMAGE, gtk.ICON_SIZE_LARGE_TOOLBAR)
-		self.set_info(unicode(_(txt_path), 'utf-8') + unicode(_(' is NOT existing!!'), 'utf-8'))
+		self.set_info(unicode(txt_path, 'utf-8') + unicode(_(' is NOT existing!!'), 'utf-8'))
 		self.disconnect_buttons()
 
 	def disconnect_buttons(self):
@@ -342,10 +340,10 @@ class SVGManagerWindow(gtk.Window):
 			self.sur_button.disconnect(self.button_id_s)
 		self.button_id_s = None
 
-	def select_row(self, treeview, se=gtk.FALSE):
+	def select_row(self, treeview, se=False):
 		if len(self.ghost_list_str) <= 0:
 			self.clear_info()
-			return gtk.TRUE
+			return True
 
 		txt_path = expand_quote(self.ghost_list_str.get_value(self.ghost_list_str.get_iter(self.ghost_list.get_cursor()[0][0]), 3))
 		txt_path = os.path.join(self.ghostmanager.get_ghost_dir(), os.path.basename(txt_path))
@@ -355,12 +353,12 @@ class SVGManagerWindow(gtk.Window):
 			#self.clear_info()
 			#self.set_info()
 			#self.info_svg_str.clear()
-			#self.sur_button.set_sensitive(gtk.FALSE)
-			#self.url_button.set_sensitive(gtk.FALSE)
+			#self.sur_button.set_sensitive(False)
+			#self.url_button.set_sensitive(False)
 			#self.ghost_name.set_text(unicode(_(txt_path), 'utf-8') + unicode(_(' is NOT existing!!'), 'utf-8'))
 			#self.sakura_box.set_from_stock(gtk.STOCK_MISSING_IMAGE, gtk.ICON_SIZE_LARGE_TOOLBAR)
 			#self.unyuu_box.set_from_stock(gtk.STOCK_MISSING_IMAGE, gtk.ICON_SIZE_LARGE_TOOLBAR)
-			return gtk.TRUE
+			return True
 
 		## get and show sakura, unyuu surfaces
 		sur_sakura = g.get_surface(0)
@@ -393,7 +391,7 @@ class SVGManagerWindow(gtk.Window):
 
 # 		self.info_svg_str.clear()
 		
-# 		for i in range(len(status)):
+# 		for i in xrange(len(status)):
 # 			self.info_svg_str.append(status[i])
 
 # 		if self.button_id:
@@ -407,12 +405,12 @@ class SVGManagerWindow(gtk.Window):
 		self.disconnect_buttons()
 
 		if hpurl:
-			self.url_button.set_sensitive(gtk.TRUE)
+			self.url_button.set_sensitive(True)
 			self.button_id = self.url_button.connect("clicked", self.url_jump, hpurl)
 		else:
-			self.url_button.set_sensitive(gtk.FALSE)
+			self.url_button.set_sensitive(False)
 
-		self.sur_button.set_sensitive(gtk.TRUE)
+		self.sur_button.set_sensitive(True)
 		self.button_id_s = self.sur_button.connect("clicked", self.show_surface, g)
 
 	def _copy_svg(self, src_file, dest_file):
@@ -473,7 +471,7 @@ class SVGManagerWindow(gtk.Window):
 		ghost_dir = self.ghostmanager.get_ghost_dir()
 
 		filew = gtk.FileSelection()
-		filew.set_select_multiple(gtk.FALSE)
+		filew.set_select_multiple(False)
 		filew.connect("destroy", lambda x: filew.destroy())
 		filew.set_filename(os.path.normpath(os.path.join(ghost_dir, '*.txt')))
 		filew.show()
@@ -482,12 +480,12 @@ class SVGManagerWindow(gtk.Window):
 		filew.destroy()
 
 		if res != gtk.RESPONSE_OK:
-			return gtk.TRUE
+			return True
 
 		ghost = self.copy_svg(src_svg_file)
 		if not ghost:
 			sys.stderr.write("!!! couldn't copy %s\n" % src_svg_file)
-			return gtk.TRUE
+			return True
 
 		ghost_name = ghost.get_sakura2()
 		if not ghost_name:
@@ -495,13 +493,13 @@ class SVGManagerWindow(gtk.Window):
 
 		if not ghost_name and not ghost.get_ghostname():
 			open_error_dialog(unicode(_("Couldn't open file"), 'utf-8'), self)
-			return gtk.TRUE
+			return True
 
-		self.ghost_list_str.append([gtk.TRUE, ghost_name, '',
+		self.ghost_list_str.append([True, ghost_name, '',
 							'"%s"' % os.path.join(os.path.basename(ghost_dir),
 												  os.path.basename(src_svg_file))])
 		self.ghost_list.set_cursor(len(self.ghost_list_str)-1)
-		return gtk.TRUE
+		return True
 
 	def check_fmo(self, button):
 		try:
@@ -570,7 +568,7 @@ class SVGManagerWindow(gtk.Window):
 
 	def url_jump(self, button, hpurl):
 		try:
-			os.system(self.browse_command % hpurl + ' &')
+			os.system(config.get('browser', 'browser_command') % hpurl + ' &')
 		except:
 			open_error_dialog(unicode(_('No selected Ghost!'), 'utf-8'), self)
 
@@ -593,11 +591,11 @@ class SVGManagerWindow(gtk.Window):
 
 	def use_ghost(self, model, iter):
 		## delete '#' from  first item '#GHOST'
-		self.ghost_list_str.set_value(iter, 0, gtk.TRUE)
+		self.ghost_list_str.set_value(iter, 0, True)
 
 	def unuse_ghost(self, model, iter):
 		## insert '#' in first item 'GHOST'
-		self.ghost_list_str.set_value(iter, 0, gtk.FALSE)
+		self.ghost_list_str.set_value(iter, 0, False)
 
 	def set_fmo(self, model, iter):
 		## insert 'FMO' the third item
