@@ -10,7 +10,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: textmanager.py,v 1.35 2004/09/29 22:07:12 atzm Exp $
+# $Id: textmanager.py,v 1.38 2005/09/08 20:03:43 atzm Exp $
 #
 
 import os
@@ -18,12 +18,12 @@ import sys
 import gtk, pango
 
 from bottleparser import *
-from prefs import PreferenceManager
 from types import *
 from common import *
+import config
 
 class TextManager(gtk.TextView):
-	def __init__(self, app, prefs, parser=BottleParser('loose')):
+	def __init__(self, app, parser=BottleParser('loose')):
 		gtk.TextView.__init__(self)
 
 		self.app = app
@@ -44,8 +44,6 @@ class TextManager(gtk.TextView):
 
 		url_tag = self.textbuffer.create_tag('URL')
 		self.font_tag = self.textbuffer.create_tag('font')
-		self.script_font = prefs.get(PreferenceManager.PREF_FONT_SCRIPT)
-		self.general_font = prefs.get(PreferenceManager.PREF_FONT_GENERAL)
 
 		# some connection
 		self.p_flag = False
@@ -54,48 +52,29 @@ class TextManager(gtk.TextView):
 		self.app.window.connect('focus-out-event', self.focus_out)
 
 		# initialize
-		self.browse_command = prefs.get(PreferenceManager.PREF_BROWSER_COMMAND)
-		self.color_changed(prefs.get(PreferenceManager.PREF_COLOR_SCRIPT),
-						   prefs.get(PreferenceManager.PREF_COLOR_SAKURA),
-						   prefs.get(PreferenceManager.PREF_COLOR_KERO),
-						   prefs.get(PreferenceManager.PREF_COLOR_SYNCHRONIZED),
-						   prefs.get(PreferenceManager.PREF_COLOR_ERROR),
-						   prefs.get(PreferenceManager.PREF_COLOR_URL))
+		self.receive_preferences_changed()
 
-	def color_changed(self, script_color, sakura_color, kero_color,
-					  sync_color, error_color, URL_color, over_color='light gray'):
+	def color_changed(self, over_color='light gray'):
 		tag_table = self.textbuffer.get_tag_table()
 
-		tag_table.lookup('script').set_property('foreground', script_color)
-		tag_table.lookup('sakura').set_property('foreground', sakura_color)
-		tag_table.lookup('kero').set_property('foreground', kero_color)
-		tag_table.lookup('sync').set_property('foreground', sync_color)
-		tag_table.lookup('error').set_property('foreground', error_color)
+		tag_table.lookup('script').set_property('foreground', config.get('fgcolor', 'script'))
+		tag_table.lookup('sakura').set_property('foreground', config.get('fgcolor', 'sakura'))
+		tag_table.lookup('kero').set_property('foreground', config.get('fgcolor', 'unyuu'))
+		tag_table.lookup('sync').set_property('foreground', config.get('fgcolor', 'synchronized'))
+		tag_table.lookup('error').set_property('foreground', config.get('fgcolor', 'error'))
 
 		url_tag = tag_table.lookup('URL')
-		url_tag.set_property('foreground', URL_color)
+		url_tag.set_property('foreground', config.get('fgcolor', 'url'))
 		url_tag.set_property('underline', pango.UNDERLINE_SINGLE)
 
 		tag_table.lookup('overURL').set_property('background', over_color)
 
-	def font_changed(self, genfont, scfont):
-		self.general_font = genfont
-		self.script_font = scfont
+	def font_changed(self):
 		self.set_style(self.view_style)
 
-	def browser_changed(self, browser):
-		self.browse_command = browser
-
-	def receive_preferences_changed(self, prefs):
-		self.color_changed(prefs[PreferenceManager.PREF_COLOR_SCRIPT],
-						   prefs[PreferenceManager.PREF_COLOR_SAKURA],
-						   prefs[PreferenceManager.PREF_COLOR_KERO],
-						   prefs[PreferenceManager.PREF_COLOR_SYNCHRONIZED],
-						   prefs[PreferenceManager.PREF_COLOR_ERROR],
-						   prefs[PreferenceManager.PREF_COLOR_URL])
-		self.font_changed(prefs[PreferenceManager.PREF_FONT_GENERAL],
-						  prefs[PreferenceManager.PREF_FONT_SCRIPT])
-		self.browser_changed(prefs[PreferenceManager.PREF_BROWSER_COMMAND])
+	def receive_preferences_changed(self):
+		self.color_changed()
+		self.font_changed()
 		self.coloring()
 
 	def receive_event(self, texttag, widget, event, iter):
@@ -110,7 +89,7 @@ class TextManager(gtk.TextView):
 
 		if event.type == 4 and \
 			   event.button and event.button == 1: # 4 left button pressed
-			os.system(self.browse_command % buf.get_text(iter, end) + ' &')
+			os.system(config.get('browser', 'browser_command') % buf.get_text(iter, end) + ' &')
 			buf.remove_tag_by_name('overURL', iter, end)
 		elif event.type == 3: # 3 mouse over?
 			self.p_flag = True
@@ -154,7 +133,7 @@ class TextManager(gtk.TextView):
 		self.textbuffer.set_text("")
 		for chunk in chunks:
 			if chunk[0] == TEXT_STRING:
-				for n in range(len(chunk[1])):
+				for n in xrange(len(chunk[1])):
 					if chunk[1][n][0] in [SCRIPT_TEXT, TEXT_META]:
 						c = chunk[1][n][1]#.replace("\\", r"\\")
 						#c = c.replace("%", r"\%")
@@ -198,7 +177,7 @@ class TextManager(gtk.TextView):
 				else:
 					format = '[%s]'
 
-				for n in range(len(args)):
+				for n in xrange(len(args)):
 					if type(args[0]) is TupleType:
 						try:
 							if args[n][0][0] == PARSE_ERROR:# and name == r'\n':
@@ -219,9 +198,9 @@ class TextManager(gtk.TextView):
 		#self.textbuffer.insert(self.textbuffer.get_end_iter(), '\n')
 		if end != pos:
 			if end != 0:
-				self.emit('move-cursor', gtk.MOVEMENT_VISUAL_POSITIONS, end*-1, gtk.FALSE)
+				self.emit('move-cursor', gtk.MOVEMENT_VISUAL_POSITIONS, end*-1, False)
 			if pos != 0:
-				self.emit('move-cursor', gtk.MOVEMENT_VISUAL_POSITIONS, pos, gtk.FALSE)
+				self.emit('move-cursor', gtk.MOVEMENT_VISUAL_POSITIONS, pos, False)
 
 	def insert_with_color_from(self, string, pos=-3):
 		current = ['sakura'] # tag stack for closable (currently only synchronized) sessions
@@ -264,7 +243,7 @@ class TextManager(gtk.TextView):
 						if current[-1] != 'sync' or name == r'\_s':
 							self.textbuffer.insert(self.textbuffer.get_end_iter(), '\n')
 					elif name == r'\URL':
-						for n in range(len(args)):
+						for n in xrange(len(args)):
 							if not n % 2 and len(args) != 1:
 								self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(),
 																		 "[%s]" % args[n][0][1], tag)
@@ -292,7 +271,7 @@ class TextManager(gtk.TextView):
 					else:
 						format = '%s[%s]'
 
-					for n in range(len(args)):
+					for n in xrange(len(args)):
 						if type(args[0]) is TupleType:
 							if not n % 2 and len(args) != 1:
 								self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(),
@@ -321,19 +300,19 @@ class TextManager(gtk.TextView):
 		self.textbuffer.apply_tag_by_name('font', si, ei)
 
 		if pos != 0:
-			self.emit("move-cursor", gtk.MOVEMENT_VISUAL_POSITIONS, pos, gtk.FALSE)
+			self.emit("move-cursor", gtk.MOVEMENT_VISUAL_POSITIONS, pos, False)
 
 	def set_style_talk(self):
 		self.view_style = STYLE_TALK
-		self.font_tag.set_property('font', self.general_font)
+		self.font_tag.set_property('font', config.get('font', 'general'))
 
 	def set_style_script(self):
 		self.view_style = STYLE_SCRIPT
-		self.font_tag.set_property('font', self.script_font)
+		self.font_tag.set_property('font', config.get('font', 'script'))
 
 	def set_style_script_with_linefeed(self):
 		self.view_style = STYLE_SCRIPT_WITH_LINEFEED
-		self.font_tag.set_property('font', self.script_font)
+		self.font_tag.set_property('font', config.get('font', 'script'))
 
 	def set_style(self, style):
 		if type(style) is not IntType:
