@@ -12,9 +12,12 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: ghost.py,v 1.13 2004/11/13 18:05:01 tkawa Exp $
+# $Id: ghost.py,v 1.18 2005/09/27 05:59:49 atzm Exp $
 #
 
+__version__ = '$Revision: 1.18 $'
+__author__ = '$Author: atzm $'
+
 import gtk
 import os
 import sys
@@ -25,9 +28,7 @@ from types import *
 from viewercommon import *
 
 class Ghost:
-	def __init__(self, svg_txt, svg_dir, debug=DEBUG):
-		self.debug = debug
-
+	def __init__(self, svg_txt, svg_dir):
 		self.svg_dir     = svg_dir
 		self.surface_dic = {}
 		self.reverse_dic = {}
@@ -47,11 +48,14 @@ class Ghost:
 		self.sakura_action = None
 		self.inform      = None
 
+		self.ghost_pixbuf = None
+
 		temporary   = None
 		last_splite = 0
 
-		if self.debug:
-			sys.stderr.write('%s\n' % ('-' * 20))
+		# toriaezu uzai
+		#if __debug__:
+		#	print >> sys.stderr, '%s' % ('-' * 20)
 		self.debugprint('Ghost def text', svg_txt)
 
 		try:
@@ -66,7 +70,8 @@ class Ghost:
 				if not line:
 					break
 
-				line = string.replace(line, '\r\n', '')
+				#line = string.replace(line, '\r\n', '')
+				line = string.rstrip(line)
 				if not line:
 					continue
 				elif line[:4] == '/EOF':
@@ -167,7 +172,7 @@ class Ghost:
 							if m:
 								sur_ein  = int(m.group(1))
 								sur_zwei = int(m.group(2))
-								for each in range(sur_ein, sur_zwei+1):
+								for each in xrange(sur_ein, sur_zwei+1):
 									self.surface_dic[each] = each
 								last_splite = sur_zwei+1
 							else:
@@ -180,7 +185,7 @@ class Ghost:
 							if m:
 								sur_ein  = int(m.group(1))
 								sur_zwei = int(m.group(2))
-								for each in range(sur_ein, sur_zwei+1):
+								for each in xrange(sur_ein, sur_zwei+1):
 									self.surface_dic[each] = last_splite
 									last_splite += 1
 							else:
@@ -194,7 +199,7 @@ class Ghost:
 							if m:
 								sur_ein  = int(m.group(1))
 								sur_zwei = int(m.group(2))
-								for each in range(sur_ein, sur_zwei+1):
+								for each in xrange(sur_ein, sur_zwei+1):
 									self.surface_dic[each] = s1
 							else:
 								s0 = int(sur[0])
@@ -218,6 +223,8 @@ class Ghost:
 		#print self.surface_dic
 		#print self.sequential_dic
 
+
+	def load_image(self):
 		image_path = os.path.join(self.svg_dir, self.surfacefile)
 		try:
 			self.ghost_pixbuf = gtk.gdk.pixbuf_new_from_file(image_path)
@@ -225,12 +232,11 @@ class Ghost:
 			self.debugprint("can't open file", image_path)
 			self.ghost_pixbuf = None
 
-	def set_debug(self, flag):
-		self.debug = bool(flag)
-
 	def debugprint(self, desc, text):
-		if self.debug:
-			sys.stderr.write("%-15s: %s\n" % (desc, text.encode('euc-jp')))
+		pass
+		# toriaezu uzai
+		#if __debug__:
+		#	print >> sys.stderr, '%-15s: %s' % (desc, text.encode('euc-jp', 'ignore'))
 
 	def __str__(self):
 		if self.sakura:
@@ -308,23 +314,25 @@ class Ghost:
 				else:
 					id = 0
 
-		if self.ghost_pixbuf is None:
-			return None
+		if self.ghost_pixbuf is None: # try to load ghost image file if not cached
+			self.load_image()
+			if self.ghost_pixbuf is None: # return None if loading failed
+				return None
+
+		if id == -1:
+			area = gtk.gdk.pixbuf_new_from_xpm_data(XPM_VANISH)
 		else:
-			if id == -1:
-				area = gtk.gdk.pixbuf_new_from_xpm_data(XPM_VANISH)
-			else:
-				svg_width  = self.ghost_pixbuf.get_width()
-				svg_height = self.ghost_pixbuf.get_height()
+			svg_width  = self.ghost_pixbuf.get_width()
+			svg_height = self.ghost_pixbuf.get_height()
 
-				x = svg_width / SIZE_SURFACE_H
-				y = svg_height / SIZE_SURFACE_V
-				a = id % x
-				b = id / x
+			x = svg_width / SIZE_SURFACE_H
+			y = svg_height / SIZE_SURFACE_V
+			a = id % x
+			b = id / x
 
-				area = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, gtk.TRUE, 8, 48, 64)
-				self.ghost_pixbuf.copy_area(SIZE_SURFACE_H * a, SIZE_SURFACE_V * b,
-											SIZE_SURFACE_H, SIZE_SURFACE_V, area, 0, 0)
+			area = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, True, 8, 48, 64)
+			self.ghost_pixbuf.copy_area(SIZE_SURFACE_H * a, SIZE_SURFACE_V * b,
+										SIZE_SURFACE_H, SIZE_SURFACE_V, area, 0, 0)
 
 		return area
 
@@ -345,23 +353,26 @@ class Ghost:
 
 	def get_surface_s(self, splite_id, side=SIDE_SAKURA):	## for Sequential Splite
 		id = int(splite_id)
-		if self.ghost_pixbuf is None:
-			return None
+
+		if self.ghost_pixbuf is None: # try to load ghost image file if not cached
+			self.load_image()
+			if self.ghost_pixbuf is None: # return None if loading failed
+				return None
+
+		if id == -1:
+			area = gtk.gdk.pixbuf_new_from_xpm_data(XPM_VANISH)
 		else:
-			if id == -1:
-				area = gtk.gdk.pixbuf_new_from_xpm_data(XPM_VANISH)
-			else:
-				svg_width  = self.ghost_pixbuf.get_width()
-				svg_height = self.ghost_pixbuf.get_height()
+			svg_width  = self.ghost_pixbuf.get_width()
+			svg_height = self.ghost_pixbuf.get_height()
 
-				x = svg_width / SIZE_SURFACE_H
-				y = svg_height / SIZE_SURFACE_V
-				a = id % x
-				b = id / x
+			x = svg_width / SIZE_SURFACE_H
+			y = svg_height / SIZE_SURFACE_V
+			a = id % x
+			b = id / x
 
-				area = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, gtk.TRUE, 8, 48, 64)
-				self.ghost_pixbuf.copy_area(SIZE_SURFACE_H * a, SIZE_SURFACE_V * b,
-											SIZE_SURFACE_H, SIZE_SURFACE_V, area, 0, 0)
+			area = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, True, 8, 48, 64)
+			self.ghost_pixbuf.copy_area(SIZE_SURFACE_H * a, SIZE_SURFACE_V * b,
+										SIZE_SURFACE_H, SIZE_SURFACE_V, area, 0, 0)
 		return area
 
 	def get_ss_group(self, surface_id):
