@@ -10,26 +10,22 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: viewercommon.py,v 1.3 2004/10/03 04:14:39 atzm Exp $
+# $Id: viewercommon.py,v 1.6 2005/09/27 05:59:49 atzm Exp $
 #
 
 import re
 
-# debug
-DEBUG = False
-
 # pixels
 SIZE_SURFACE_H = 48
 SIZE_SURFACE_V = 64
 
 # vanish image
 XPM_VANISH = [
-	"16 16 3 1",
-	"       c None",
-	".      c #000000000000",
-	"X      c #FFFFFFFFFFFF"
+	"%d %d 2 1" % (SIZE_SURFACE_H, SIZE_SURFACE_V),
+	" \tc #FFFFFF",
+	".\tc #000000",
 	]
-XPM_VANISH += [' ' * SIZE_SURFACE_H for a in range(SIZE_SURFACE_V)]
+XPM_VANISH += [' ' * SIZE_SURFACE_H for i in xrange(SIZE_SURFACE_V)]
 
 # sides
 SIDE_SAKURA = 0
